Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(735)

Unified Diff: Source/core/css/resolver/StyleBuilderCustom.cpp

Issue 100453011: Rename css/CSSParser to css/parser/BisonCSSParser. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/css/resolver/FilterOperationResolver.cpp ('k') | Source/core/css/resolver/StyleResolver.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/css/resolver/StyleBuilderCustom.cpp
diff --git a/Source/core/css/resolver/StyleBuilderCustom.cpp b/Source/core/css/resolver/StyleBuilderCustom.cpp
index 8ba83747b94773a129bde4d374907f2d835b0afa..e994e2417bc8f14a340da9de9229a39696da8fa8 100755
--- a/Source/core/css/resolver/StyleBuilderCustom.cpp
+++ b/Source/core/css/resolver/StyleBuilderCustom.cpp
@@ -53,7 +53,7 @@
#include "core/css/CSSHelper.h"
#include "core/css/CSSImageSetValue.h"
#include "core/css/CSSLineBoxContainValue.h"
-#include "core/css/CSSParser.h"
+#include "core/css/parser/BisonCSSParser.h"
#include "core/css/CSSPrimitiveValueMappings.h"
#include "core/css/CSSProperty.h"
#include "core/css/CSSReflectValue.h"
@@ -439,7 +439,7 @@ void StyleBuilderFunctions::applyValueCSSPropertySize(StyleResolverState& state,
height = second->computeLength<Length>(state.cssToLengthConversionData().copyWithAdjustedZoom(1.0));
} else {
// <page-size> <orientation>
// The value order is guaranteed. See CSSParser::parseSizeParameter.
if (!getPageSizeFromName(first, second, width, height))
return;
}
@@ -533,7 +533,7 @@ void StyleBuilderFunctions::applyValueCSSPropertyTextIndent(StyleResolverState&
return;
// [ <length> | <percentage> ] each-line
// The order is guaranteed. See CSSParser::parseTextIndent.
// The second value, each-line is handled only when css3TextEnabled() returns true.
CSSValueList* valueList = toCSSValueList(value);
@@ -1109,7 +1109,7 @@ static void resolveVariables(StyleResolverState& state, CSSPropertyID id, CSSVal
// FIXME: It would be faster not to re-parse from strings, but for now CSS property validation lives inside the parser so we do it there.
RefPtr<MutableStylePropertySet> resultSet = MutableStylePropertySet::create();
- if (!CSSParser::parseValue(resultSet.get(), id, expression.second, false, state.document()))
+ if (!BisonCSSParser::parseValue(resultSet.get(), id, expression.second, false, state.document()))
return; // expression failed to parse.
for (unsigned i = 0; i < resultSet->propertyCount(); i++) {
« no previous file with comments | « Source/core/css/resolver/FilterOperationResolver.cpp ('k') | Source/core/css/resolver/StyleResolver.cpp » ('j') | no next file with comments »
@@ -439,7 +439,7 @@ void StyleBuilderFunctions::applyValueCSSPropertySize(StyleResolverState& state,
} else {
// <page-size> <orientation>
- // The value order is guaranteed. See CSSParser::parseSizeParameter.
+ // The value order is guaranteed. See BisonCSSParser::parseSizeParameter.
if (!getPageSizeFromName(first, second, width, height))
return;
@@ -533,7 +533,7 @@ void StyleBuilderFunctions::applyValueCSSPropertyTextIndent(StyleResolverState&
return;
// [ <length> | <percentage> ] each-line
- // The order is guaranteed. See CSSParser::parseTextIndent.
+ // The order is guaranteed. See BisonCSSParser::parseTextIndent.
// The second value, each-line is handled only when css3TextEnabled() returns true.
CSSValueList* valueList = toCSSValueList(value);

Powered by Google App Engine
This is Rietveld 408576698